{% load static %}
{% load i18n %}

{% include 'django/forms/widgets/input.html' %}

<a href="{{ related_url }}{{ url }}"
   data-name="{{ name }}"
   data-app="{{ app_name }}"
   data-model="{{ model_name }}"
   class="dynamic_raw_id-related-lookup"
   id="lookup_id_{{ name }}"
   style="display: inline-block; cursor: pointer;"
   title="{% trans "Search" %}">
    <img src="{% static "admin/img/search.svg" %}" alt="Lookup" height="13" width="13">
</a>
<a data-name="developers"
   data-app="{{ app_name }}"
   data-model="{{ model_name }}"
   class="dynamic_raw_id-clear-field"
   style="display: inline-block; cursor: pointer;"
   title="{% trans "Remove" %}">
    <img src="{% static "admin/img/icon-deletelink.svg" %}" alt="Clear" height="13" width="13">
</a>
<span class="dynamic_raw_id_label" id="{{ name }}_dynamic_raw_id_label"></span>
